@@ -357,8 +357,7 @@ class Model:
         for name in self.variablenames:
             if 'tbl' in name:
                 n = 0
-                for tbl in data['table']:
-                    print(tbl)
+                for tbl in data['table'].keys():
                     if name == tbl:
                         n += 1
                 dict.update({name:[positions[name],n]})
